[−][src]Struct rand::distributions::RandSample
pub struct RandSample<Sup> { /* fields omitted */ }A wrapper for generating types that implement Rand via the
Sample & IndependentSample traits.
Methods
impl<Sup> RandSample<Sup>[src]
impl<Sup> RandSample<Sup>pub fn new() -> RandSample<Sup>[src]
pub fn new() -> RandSample<Sup>Trait Implementations
impl<Sup: Debug> Debug for RandSample<Sup>[src]
impl<Sup: Debug> Debug for RandSample<Sup>fn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl<Sup> Copy for RandSample<Sup>[src]
impl<Sup> Copy for RandSample<Sup>impl<Sup> Clone for RandSample<Sup>[src]
impl<Sup> Clone for RandSample<Sup>fn clone(&self) -> Self[src]
fn clone(&self) -> SelfReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl<Sup: Rand> Sample<Sup> for RandSample<Sup>[src]
impl<Sup: Rand> Sample<Sup> for RandSample<Sup>fn sample<R: Rng>(&mut self, rng: &mut R) -> Sup[src]
fn sample<R: Rng>(&mut self, rng: &mut R) -> SupGenerate a random value of Support, using rng as the source of randomness. Read more
impl<Sup: Rand> IndependentSample<Sup> for RandSample<Sup>[src]
impl<Sup: Rand> IndependentSample<Sup> for RandSample<Sup>fn ind_sample<R: Rng>(&self, rng: &mut R) -> Sup[src]
fn ind_sample<R: Rng>(&self, rng: &mut R) -> SupGenerate a random value.